@@ -2,7 +2,7 @@ import base64
 import hashlib
 import time
 from typing import Optional
-from requests.exceptions import ConnectionError
+import requests
 from huawei_lte_api.enums.user import PasswordTypeEnum, LoginStateEnum, LoginErrorEnum
 from huawei_lte_api.enums.client import ResponseEnum
 from huawei_lte_api.ApiGroup import ApiGroup
@@ -22,7 +22,7 @@ class User(ApiGroup):
     _password = None
 
     def __init__(self, connection: Connection, username: Optional[str]=None, password: Optional[str]=None):
-        super(User, self).__init__(connection)
+        super().__init__(connection)
         self._username = username if username else 'admin'
         self._password = password
 
@@ -79,10 +79,11 @@ class User(ApiGroup):
         for i in range(tries):
             try:
                 state_login = self.state_login()
-            except ConnectionError as e:
+            except requests.exceptions.ConnectionError:
                 # Some models reportedly close the connection if we attempt to access login state too soon after
                 # setting up the session etc. In that case, retry a few times. The error is reported to be
-                # ConnectionError: ('Connection aborted.', RemoteDisconnected('Remote end closed connection without response'))
+                # ConnectionError: (
+                #     'Connection aborted.', RemoteDisconnected('Remote end closed connection without response'))
                 if i == tries - 1:
                     raise
                 time.sleep((i + 1)/10)
